from typing import (
    Callable,
    Optional,
)

import pyramid.config
import pyramid.renderers
import pyramid.request
import pyramid.response

__author__ = "Motoki Naruse"
__copyright__ = "Motoki Naruse"
__credits__ = ["Motoki Naruse"]
__email__ = "motoki@naru.se"
__license__ = "MIT"
__maintainer__ = "Motoki Naruse"
__version__ = '0.0.1'


class JsonResponse:
    def __init__(self) -> None:
        self.json_renderer = pyramid.renderers.JSON()

    def _dump_json(self, source, request: Optional[pyramid.request.Request]) -> str:
        return self.json_renderer(None)(source, {'request': request} if request else {})

    def dump_json(self, request: pyramid.request.Request, source) -> str:
        return self._dump_json(source, None)

    def response_json(self, request: pyramid.request.Request, body, status=None) -> Callable:
        json_body = self._dump_json(body, request)

        return pyramid.response.Response(
            json_body,
            status=status,
            headerlist=[
                ('Content-Length', str(len(json_body))),
                ('Content-Type', 'application/json'),
            ],
            charset="utf-8"
        )

    def add_adapter(self, request: pyramid.request.Request, type_or_iface, adapter) -> None:
        self.json_renderer.add_adapter(type_or_iface, adapter)


def includeme(config: pyramid.config.Configurator) -> None:
    json_response = JsonResponse()
    config.add_directive('add_json_adapter', json_response.add_adapter)
    config.add_request_method(json_response.dump_json, name="dump_json")
    config.add_request_method(json_response.response_json, name="response_json")



#!/usr/bin/env python3
import os
import re
import setuptools
from typing import Dict


here = os.path.abspath(os.path.dirname(__file__))


def get_meta() -> Dict[str, str]:
    with open(os.path.join(here, 'pyramid_json_response.py')) as f:
        source = f.read()

    regex = r'^{}\s*=\s*[\'"]([^\'"]*)[\'"]'
    return lambda name: re.search(regex.format(name), source, re.MULTILINE).group(1)


get_meta = get_meta()

install_requires = []

test_requires = [
    'flake8',
    'mypy',
    'pytest',
    'pytest-cov',
]

setuptools.setup(
    name='pyramid_json_response',
    version=get_meta('__version__'),
    description="",
    long_description="",
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Software Development :: Libraries"
    ],
    keywords=["pyramid"],
    author=get_meta('__author__'),
    author_email=get_meta('__email__'),
    url="https://github.com/narusemotoki/pyramid_json_response",
    license=get_meta('__license__'),
    py_modules=['pyramid_json_response'],
    install_requires=install_requires,
    extras_require={
        'test': test_requires,
    },
    include_package_data=True,
)
